==> charcoal-0.3.2.tar.gz: charcoal-0.3.2/charcoal/charcoal.inc.php <==
<?php

error_reporting(E_ALL);

//==================================================================
// OSˤäƥѥڤʸȽ

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// 

define( 'PROC_KEYWORD', 'proc' );

//==================================================================
// 󥯥롼ɥѥ

ini_set(
		'include_path', 
//		'.' 
		PATH_SEPARATOR . CHARCOAL_HOME
		. PATH_SEPARATOR . EXTLIB_DIR
		. PATH_SEPARATOR . WEBAPP_DIR . "/" . APPLICATION . "/classes/"
	);

//==================================================================
// autoload

function __autoload( $class_name )
{
	require_once ( 'classes/core/ClassLoader.class.php' );

	$loaded = charcoal_ClassLoader::loadClass( $class_name );
}

//==================================================================
// ϴؿ

// TRACE
function log_trace( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "T:$logger_names", $message, $file, $line );
}

// INFO
function log_info( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "I:$logger_names", $message, $file, $line );
}

// WARNING
function log_warning( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "W:$logger_names", $message, $file, $line );
}

// DEBUG
function log_debug( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "D:$logger_names", $message, $file, $line );
}

// ERROR
function log_error( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "E:$logger_names", $message, $file, $line );
}

// FATAL
function log_fatal( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "F:$logger_names", $message, $file, $line );
}

//==================================================================
// 

function array_dump( $array, $title = NULL )
{
	print charcoal_System::arrayToString($array,$title);
}


//==================================================================
// ץեɤ߹

$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
//$host = $_SERVER["SERVER_NAME"];

charcoal_Profile::load( $host );

==> charcoal-0.4.0.tar.gz: charcoal-0.4.0/charcoal/charcoal.inc.php <==
<?php

// 桼ˤǤ̵뤹
ignore_user_abort( TRUE );

//error_reporting(E_ALL);


//==================================================================
// OSˤäƥѥڤʸȽ

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// 

define( 'PROC_KEYWORD', 'proc' );

//==================================================================
// 󥯥롼ɥѥ

ini_set(
		'include_path', 
//		'.' 
		PATH_SEPARATOR . CHARCOAL_HOME . '/classes/'
		. PATH_SEPARATOR . EXTLIB_DIR
		. PATH_SEPARATOR . WEBAPP_DIR . '/' . APPLICATION . '/classes/'
	);

//==================================================================
// autoload

function __autoload( $class_name )
{
	require_once ( 'core/ClassLoader.class.php' );

	$loaded = charcoal_ClassLoader::loadClass( $class_name );
}

//==================================================================
// ϴؿ

// TRACE
function log_trace( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "T:$logger_names", $message, $file, $line );
}

// INFO
function log_info( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "I:$logger_names", $message, $file, $line );
}

// WARNING
function log_warning( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "W:$logger_names", $message, $file, $line );
}

// DEBUG
function log_debug( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "D:$logger_names", $message, $file, $line );
}

// ERROR
function log_error( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "E:$logger_names", $message, $file, $line );
}

// FATAL
function log_fatal( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "F:$logger_names", $message, $file, $line );
}

//==================================================================
// 

function array_dump( $array, $title = NULL )
{
	print charcoal_System::arrayToString($array,$title);
}

//==================================================================
// ץߥƥؿ

function s( $value, $encoding = NULL )
{
	return new charcoal_String( $value, $encoding );
}

function i( $value )
{
	return new charcoal_Integer( $value );
}

//==================================================================
// ץեɤ߹

$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
//$host = $_SERVER["SERVER_NAME"];

charcoal_Profile::load( $host );

// ॢȤ
$timeout = charcoal_Profile::getInteger("SCRIPT_TIMEOUT",600);
set_time_limit( $timeout );
